﻿using System;
using System.Net;
using System.Web.UI;
using System.IO;
using System.Web.UI.WebControls;
using System.Drawing;
using System.Drawing.Drawing2D;

public partial class FetchImage : System.Web.UI.Page
{
  
    protected void Page_Load(object sender, EventArgs e)
    {
    }

    private void FetchImageFromUrl(String url,String path)
    {
      // se zadanou URL si připravíme HttpWebRequest
      HttpWebRequest getImageRequest = (HttpWebRequest) WebRequest.Create(new Uri(url));
      // kdyby byl z našeho serveru potřeba přístup přes proxy, stačí odkomentovat následující
      //getImageRequest.Proxy = new WebProxy(); 
      //getImageRequest.Proxy.Credentials = new NetworkCredential();
      //getImageRequest.PreAuthenticate = true;
      //getImageRequest.Credentials = new System.Net.NetworkCredential(UserName,UserPassword);
      try
      {
        // HttpWebResponse nám vrátí stream odpovědi serveru
        using (System.Net.HttpWebResponse getImageResponse = (HttpWebResponse) getImageRequest.GetResponse())
        {
          if (getImageRequest.HaveResponse && getImageResponse.ContentLength != 0)
          {  // pokud se vůbec něco stáhlo a nemá nulovou délku, můžeme to uložit na disk
            Image_SaveToDisc(getImageResponse.GetResponseStream(), 300, 400, path);
          }
          else
          {
            //nepřečetlo se nebo má nulovou délku
          }
          // pěkně po sobě uklidíme
          getImageResponse.Close();
        }
      }
      catch (System.Net.WebException netEx)
      { // síťová chyba
      }
      catch(Exception Ex)
      { // jiná chyba
      }
    }


    private void Image_SaveToDisc(Stream image, int maxWidth, int maxHeight, string path)
    {
      bool isLandscape = false;
    
      // ze streamu vytvoříme nový objekt obrázku
      using (System.Drawing.Image sourcePicture = System.Drawing.Image.FromStream(image, false, true))
      {
        // je obrázek "naležato"?
        isLandscape = (sourcePicture.Width > sourcePicture.Height);
        // velikost "delší" strany
        int longerSideLength = (isLandscape) ? sourcePicture.Width : sourcePicture.Height;
    
        // pokud má obrázek některou stranu větší než maximum, musíme zmenšit
        if (longerSideLength > maxWidth || longerSideLength > maxHeight)
        {
          // vypočteme poměr stran
          decimal originalAspectRatio = ((decimal)sourcePicture.Width / (decimal)sourcePicture.Height);
          // připravíme novou šířku 
          int newPictureWidth = (int)(Decimal.Round(((decimal)maxHeight * originalAspectRatio), 0));
          // připravíme novou výšku
          int newPictureHeight = maxHeight;
    
          // pokud dopočítaná šířka překročí maximální 
          if (newPictureWidth >= maxWidth)
          {
            // nastavíme maximální šířku
            newPictureWidth = maxWidth;
            // a dopočítáme výšku
            newPictureHeight = (int)(Decimal.Round(((decimal)maxWidth / originalAspectRatio), 0));
          }
    
          // připravíme "prázdný" obrázek o nových rozměrech
          using (Bitmap resizedPicture = new Bitmap(newPictureWidth, newPictureHeight))
          {
            // připravíme objekt Graphic nad prázdným obrázkem
            using (Graphics oGraphic = Graphics.FromImage(resizedPicture))
            {  // nastavíme vlastnosti pro úpravy obrázku
              oGraphic.CompositingQuality = CompositingQuality.HighQuality;
              oGraphic.SmoothingMode = SmoothingMode.HighQuality;
              oGraphic.InterpolationMode = InterpolationMode.HighQualityBicubic;
              // a nakonec původní obrázek rozkreslíme do nového "prázdného"
              oGraphic.DrawImage(sourcePicture, 0, 0, newPictureWidth, newPictureHeight);
            }
            try
            { // uložíme nově upravený obrázek
              resizedPicture.Save(path, System.Drawing.Imaging.ImageFormat.Jpeg);
            }
            catch (Exception Ex)
            {
              //chyba při ukládání souboru;
            }
          }
        }
        else
        { // obrázek je menší než maximum, uložíme bez úprav
          try
          {
            sourcePicture.Save(path, System.Drawing.Imaging.ImageFormat.Jpeg);
          }
          catch (Exception Ex)
          {
            //chyba při ukládání souboru;
          }
        }
      }
    } 

    protected void Button1_Click(object sender, EventArgs e)
    {
      FetchImageFromUrl(TextBox1.Text, "C:\\FetchImage\\FetchImage.jpg");
    }
}
